summaryrefslogtreecommitdiff
path: root/test/suite/test_compact02.py
diff options
context:
space:
mode:
Diffstat (limited to 'test/suite/test_compact02.py')
-rw-r--r--test/suite/test_compact02.py5
1 files changed, 3 insertions, 2 deletions
diff --git a/test/suite/test_compact02.py b/test/suite/test_compact02.py
index 14781b0f050..7ad05cd2536 100644
--- a/test/suite/test_compact02.py
+++ b/test/suite/test_compact02.py
@@ -50,11 +50,12 @@ class test_compact02(wttest.WiredTigerTestCase):
# being stored: compaction doesn't work on tables with many overflow items
# because we don't rewrite them. Experimentally, 8KB is as small as the test
# can go. Additionally, we can't set the maximum page size too large because
# there won't be enough pages to rewrite. Experimentally, 32KB (the default)
# is as large as the test can go.
fileConfig = [
('default', dict(fileConfig='')),
('8KB', dict(fileConfig='leaf_page_max=8kb')),
+ ('64KB', dict(fileConfig='leaf_page_max=64KB')),
+ ('128KB', dict(fileConfig='leaf_page_max=128KB')),
]
scenarios = \
number_scenarios(multiply_scenarios('.', types, cacheSize, fileConfig))
@@ -50,11 +50,12 @@ class test_compact02(wttest.WiredTigerTestCase):
# because we don't rewrite them. Experimentally, 8KB is as small as the test
# can go. Additionally, we can't set the maximum page size too large because
- # there won't be enough pages to rewrite. Experimentally, 32KB (the default)
- # is as large as the test can go.
+ # there won't be enough pages to rewrite. Experimentally, 128KB works.
fileConfig = [
('default', dict(fileConfig='')),